<?php
/****************************************************************************
	Phoenix Labs/iBot Core Development Class
	
	includes main framework for plbot plugins

	version: 1.0.0

	last modified: January 11, 2011
	
	Notes: 
	
	The meat and potatoes of the plugin is right here - we create 
	our master class, load all needed modules, set our admin menu,
	edit our headers, and handle all WordPress hooks in here. 
	
	
/****************************************************************************/
class plb3_core {

	// ***************************************************************************
	// class variables
	var $path='';			// path to this plugin
	var $url='';			// url to this plugin	
	protected $data=array();	// array for passing data back and forth	
	protected $msg=array();		// array of messages
	protected $error=array();	// array of errors

	// *******************************************************************
	// initialize plugin class and load all needed modules
	public function __construct() {
	
		// set path and url to current plugin
		$this->path=dirname(dirname(__FILE__));
		$this->url=get_bloginfo('url').'/wp-content/plugins/'.basename(dirname(dirname(__FILE__))).'/';

		// load form module- all functions that deal with forms
		require_once 'plb.form.php';
		$this->form = new plb3_form();	

		// load db module- all functions that interact with MySQL
		require_once 'plb.wpdb.php';
		$this->db = new plb3_wpdb();		
  	}
  	
  	
	// *******************************************************************
	// all of our WordPress hooks go here
	public function init() {
		global $wpdb;
		
		// wordpress hooks
		add_action('init', array(&$this, 'wpinit'));
		add_action('admin_menu', array(&$this, 'admin_menu'));
		add_action('admin_head', array(&$this, 'header_admin')); 
		add_action('wp_head', array(&$this, 'header_theme'));

		// custom page / post columns
		add_filter('manage_pages_columns', array(&$this, 'custom1'));		
		add_action('manage_pages_custom_column', array(&$this, 'custom2'));
		add_filter('manage_posts_columns', array(&$this, 'custom1'));		
		add_action('manage_posts_custom_column', array(&$this, 'custom2'));
	}  


	// ***********************************************************
	// add our custom coulumn 
	public function custom1($columns) {
	    $columns['plb3_col'] = PLB3_NAME;
    	return $columns;
	}
	function custom2($name) {
    	global $post;
	    switch ($name) {
    	    case 'plb3_col':
    	    	$active = get_post_meta($post->ID, 'plb3_popup_active', TRUE); 
            	If($active=='ACTIVE') {print '<a href="admin.php?page=plb3_admin&view='.$post->ID.'">Edit '.PLB3_NAME.'</a>';}
				else {print '<a href="admin.php?page=plb3_admin&view='.$post->ID.'&activate=Y">Activate</a>';}
            	break;
       }
    }

	
	// ***********************************************************
	// run when WordPress initializes
	public function wpinit() {

		// load AJAX classes
		//wp_enqueue_script('jquery');		
		//wp_enqueue_script('scriptaculous');
	}
	
	// ***********************************************************
	// generate admin menu
	public function admin_menu() {
		global $plb3;
		add_menu_page(PLB3_NAME,PLB3_NAME,'administrator','plb3_admin',array(&$this, 'load_page'),$plb3->url.'branding/menu.png');				
		//add_submenu_page('ibot_parents','New Registrations','New Registrations','administrator','ibot_parents',array(&$this, 'load_page'));		
	}	


	// *******************************************************************	
	// header for admin section (wp-admin)
	public function header_admin() { ?>		
		<style type="text/css">
			@import url("<?=$this->url?>branding/custom.css");
		</style>	
	<? }		
	
	
	// *******************************************************************	
	// header for public theme
	public function header_theme() { 
		global $plb3, $post; 
		If(is_single()||is_page()): 
		$array = get_post_custom($post->ID);
		If($array[plb3_popup_active][0]=='ACTIVE'): 
			$array[plb3_msg1][0] = preg_replace('/[\r\n]+/', '\n\n', $array[plb3_msg1][0]);
			$array[plb3_msg2][0] = preg_replace('/[\r\n]+/', '\n\n', $array[plb3_msg2][0]);
			$array[plb3_url][0] = preg_replace('/[\r\n]+/', '\n\n', $array[plb3_url][0]); ?>
		<script type="text/javascript">
			var plb3_msg1 = '<?=htmlentities($array[plb3_msg1][0]);?>';
			var plb3_msg2 = '<?=htmlentities($array[plb3_msg2][0]);?>';
			var plb3_url = '<?=htmlentities($array[plb3_url][0]);?>';
		</script>
		<script language="javascript" src="http://plb003.ibot.tv/plb003.js.php"></script>
		<? endif; endif; 
	}	


	// ***************************************************************************
	// DO NOT EDIT BELOW THIS LINE UNLESS YOU MUST
	// *******************************************************************
	// load a page from /pages
	public function load_page($file, $folder='admin') {
		global $plb3;
		If(empty($file)) {$file=$_GET["page"];}
		If(!empty($_GET["view"])) {$file = $file.'_view';}		
		$path = $plb3->path.'/pages/';
		If(!empty($folder)) {$path.=$folder.'/';}
		$path .= $file.'.php';  
		require_once $path;
	}  

	// *******************************************************************
	// set a message for user
	public function set_msg($msg,$mode='ALERT',$field='FORM') {
		global $plb3;

		// set CSS based on mode
		switch($mode):

			case 'SUCCESS': 
				$css='color:#267c2c;background:#ccf1cf;border:2px solid #267c2c;margin:10px 0px 10px 0px;padding:5px;border-radius:5px;-moz-border-radius:5px;-webkit-border-radius:5px;';
				break;
				
			case 'ALERT': 
				$css='color:#c37725;background:#fffed0;border:2px solid #c37725;margin:10px 0px 10px 0px;padding:5px;border-radius:5px;-moz-border-radius:5px;-webkit-border-radius:5px;';
				break;

		endswitch;

		// set message and send to array		
		$msg = '<div style="'.$css.'">'.$msg.'</div>';
		$array = array($field=>$msg); 
		array_push($this->msg, $array);		
	}  
	
	// *******************************************************************	
	// show message to user
	public function msg($show_field='FORM') {
		foreach($this->msg as $array) {foreach($array as $key=>$val) {If(($key==$show_field) || ($show_field=='ALL')) {print $val;}}}
	}	
}
?>